@@ -1,13 +1,17 @@
+echo "MySQL MyISAM..."
+tedia2sql -i TestERD.dia -o mysql-testerd.sql -d -t mysql
+echo "MySQL InnoDB..."
+tedia2sql -i TestERD.dia -o innodb-testerd.sql -d -t innodb
+echo "Postgres..."
+tedia2sql -i TestERD.dia -o pgsql-testerd.sql -d -t postgres
 echo "DB2..."
 tedia2sql -i TestERD.dia -o db2-testerd.sql -d -t db2
 echo "Oracle..."
 tedia2sql -i TestERD.dia -o oracle-testerd.sql -d -t oracle
-echo "Postgres..."
-tedia2sql -i TestERD.dia -o pgsql-testerd.sql -d -t postgres
 echo "Sybase..."
 tedia2sql -i TestERD.dia -o sybase-testerd.sql -d -t sybase
 echo "Ingres..."
 tedia2sql -i TestERD.dia -o ingres-testerd.sql -d -t ingres
-echo "MySQL InnoDB..."
-tedia2sql -i TestERD.dia -o innodb-testerd.sql -d -t innodb
+echo "SAS..."
+tedia2sql -i TestERD.dia -o sas-testerd.sql -d -t sas
 
